ynabr: Access the You Need A Budget API

Description

Description

You Need A Budget (YNAB) is budgeting software and this package provides access to the YNAB API. The likely use case is for users wanting to augment the YNAB reports and graphs with custom generated ones.


jhollist/ynabr documentation built on Dec. 31, 2019, 12:55 a.m.